¿Cómo se hace un videojuego? — titulo...

# ¿Cómo se hace un videojuego?

Para hacer videojuegos vamos a usar una herramienta llamadas `pilas`.

En esta herramienta, el código inicial tiene que ser algo así:

    import pilas
    pilas.iniciar()

prueba haciendo `click` en el código y luego pulsando el botón `ejecutar`.

## Agregando actores

Los actores son personajes para nuestro juego: naves, animales, sombreros, estrellas, etc.

Así se puede llegar a ver un actor:

Todos estos actores se pueden crear escribiendo `pilas.actores` seguido de un punto y el nombre del actor.

Por ejemplo, este código creará una nave que se puede mover con el teclado:

    import pilas
    pilas.iniciar()

    pilas.actores.Nave()

Ahora, cuando pulses el botón `ejecutar`, vas a ver una nave que se puede controlar con el teclado.

Con las flechas del teclado la nave puede girar y avanzar, y con la tecla `espacio` puede disparar.